import { IPlurals } from './core';
export interface ILocales {
    [key: string]: number | string | boolean | ILocales | ILocales[];
}
export declare type IFallbacks = Record<string, string>;
export declare type IUnknownPhraseListener = (locale: string, phrase: string, value: string | IPlurals) => void;
export declare type IProcessor = (text: string, namedValues: any, values: any[], count?: number) => string;
export interface IConfig {
    /**
     * Default locale to use.
     */
    defaultLocale?: string;
    /**
     * Store of translations.
     */
    locales?: ILocales;
    /**
     * Fallbacks map for locales.
     */
    fallbacks?: IFallbacks;
    /**
     * Translate phrases or get phrases by keys.
     */
    objectNotation?: boolean;
    /**
     * Cookie name to store locale.
     */
    cookieName?: string;
    /**
     * Query parameter to get locale.
     */
    queryParameter?: string;
    /**
     * Unknown phrases listener.
     */
    unknownPhraseListener?: IUnknownPhraseListener;
    /**
     * List of post processors.
     */
    processors?: IProcessor[];
}
declare type IForkConfig = Pick<IConfig, Exclude<keyof IConfig, 'objectNotation' | 'cookieName' | 'queryParameter'>>;
declare type IFunction = (...args: any[]) => any;
export default class Config implements IConfig {
    defaultLocale: string;
    locales: ILocales;
    fallbacks: IFallbacks;
    objectNotation: boolean;
    cookieName: string;
    queryParameter: string;
    unknownPhraseListener: IUnknownPhraseListener;
    processors: IProcessor[];
    isDestroyed: boolean;
    private readonly isConstructed;
    private isFork;
    private forks;
    private forkLinkedFields;
    constructor(config?: IConfig, isFork?: boolean);
    /**
     * Change config.
     * @param  config - Config options.
     * @return Config.
     */
    configure({ defaultLocale, locales, fallbacks, objectNotation, cookieName, queryParameter, unknownPhraseListener, processors }: IConfig): this;
    /**
     * Destroy instance.
     */
    destroy(): void;
    /**
     * Copy current config with some overrides.
     * @param  config - Config with overrides.
     * @return Forked config.
     */
    fork(config: IForkConfig, hard?: false): Config;
    /**
     * Copy current config with some overrides.
     * @param  config - Config with overrides.
     * @param  hard - Do hard fork without linked fields.
     * @return Forked config.
     */
    fork(config: IConfig, hard: true): Config;
    /**
     * Call given method for all forks.
     * @param caller - Function to call method of fork.
     * @param flagName - Flag name to check ability to call method.
     */
    private callForkMethod;
    /**
     * Create translate function copy, binded to another config.
     * @param  fn - Translate function.
     * @return Binded function.
     */
    bind<T extends IFunction>(fn: T): T;
    /**
     * Create translate functions copy, binded to another config.
     * @param  fns - Translate functions.
     * @return Binded functions.
     */
    bind<A extends IFunction, B extends IFunction, C extends IFunction, D extends IFunction>(fns: [A?, B?, C?, D?]): [A?, B?, C?, D?];
    /**
     * Set function to call when unknown phrase was translated.
     * @param  listener - Locale change listener.
     * @return Config.
     */
    onUnknownPhrase(listener: IUnknownPhraseListener): this;
    /**
     * Set current locale.
     * @param  locale - Locale to set.
     * @return Config.
     */
    setLocale(locale: string): this;
    /**
     * Get current locale.
     * @param  checkFallback - Flag to use fallback or not.
     * @param  localeToCheck - Locale to handle.
     * @param  strict - Should fall back to default locale or not.
     * @return Current locale.
     */
    getLocale(checkFallback?: true, localeToCheck?: string, strict?: boolean): string;
    /**
     * Get array of available locales.
     * @return Available locales.
     */
    getLocales(): string[];
    /**
     * Returns a whole catalog optionally based on given locale.
     * @param  locale - Locale to get sub-catalog.
     * @return Catalog.
     */
    getCatalog(locale?: string): ILocales | ILocales[];
    /**
     * Add new translations.
     * @param  locale - Locale to add.
     * @param  catalog - Catalog for localte to add.
     * @return Config.
     */
    addLocale(locale: string, catalog: ILocales): this;
    /**
     * Remove translations.
     * @param  locale - Locale to remove.
     * @return Config.
     */
    removeLocale(locale: string): this;
}
export {};
//# sourceMappingURL=config.d.ts.map